@@ -1,13 +1,16 @@
 from .abstract import StopCriterion
+from ..executors.outcome import Outcome
 
 
 class CountingStop(StopCriterion):
-    def __init__(self, n_total, n_random):
+    def __init__(self, n_total, n_random, count_invalid=False):
         self.n_total = n_total
         self.n_random = n_random
+        self.count_invalid = count_invalid
 
         self.exec_count = 0
 
+
     @property
     def is_over(self) -> bool:
         return self.exec_count >= self.n_total
@@ -17,4 +20,5 @@ class CountingStop(StopCriterion):
         return self.exec_count < self.n_random
 
     def execute_test(self, test):
-        self.exec_count += 1
+        if self.count_invalid or test["outcome"] != Outcome.INVALID:
+            self.exec_count += 1
